@@ -504,7 +504,7 @@ Cassette <- R6::R6Class(
     #' @description get http interactions from the cassette via the serializer
     #' @return list
     deserialized_hash = function() {
-      tmp <- self$serializer$deserialize()
+      tmp <- self$serializer$deserialize(self)
       if (inherits(tmp, "list")) {
         return(tmp)
       } else {
@@ -521,7 +521,7 @@ Cassette <- R6::R6Class(
           response <- VcrResponse$new(
             z$response$status,
             z$response$headers,
-            z$response$body$string,
+            z$response$body$string %||% z$response$body$base64_string,
             opts = self$cassette_opts,
             disk = z$response$body$file
           )
