@@ -1,17 +1,22 @@
-#' Use a cassette
+#' Use a cassette to record HTTP requests
 #'
 #' @export
-#' @param name The name of the cassette. vcr will sanitize this to ensure it
-#' is a valid file name.
-#' @param ... a block of code to evalulate, wrapped in curly braces. required.
-#' if you don't pass a code block you'll get a stop message. if you can't pass
-#' a code block use instead [insert_cassette()]
-#' @param record The record mode. Default: "once". In the future we'll support
-#' "once", "all", "none", "new_episodes". See [recording] for more information
+#' @inherit check_cassette_names details
+#' @param name The name of the cassette. vcr will check this to ensure it
+#' is a valid file name. Not allowed: spaces, file extensions, control
+#' characters (e.g., `\n`), illegal characters ('/', '?', '<', '>', '\\', ':',
+#' '*', '|', and '\"'), dots alone (e.g., '.', '..'), Windows reserved
+#' words (e.g., 'com1'), trailing dots (can cause problems on Windows),
+#' names longer than 255 characters. See section "Cassette names"
+#' @param ... a block of code containing one or more requests (required). Use
+#' curly braces to encapsulate multi-line code blocks. If you can't pass a code
+#' block use [insert_cassette()] instead.
+#' @param record The record mode (default: `"once"`). See [recording] for a
+#' complete list of the different recording modes.
 #' @param match_requests_on List of request matchers
 #' to use to determine what recorded HTTP interaction to replay. Defaults to
 #' `["method", "uri"]`. The built-in matchers are "method", "uri", "host",
-#' "path", "headers" and "body"
+#' "path", "headers", "body" and "query"
 #' @param update_content_length_header (logical) Whether or
 #' not to overwrite the `Content-Length` header of the responses to
 #' match the length of the response body. Default: `FALSE`
@@ -19,10 +24,13 @@
 #' allow a single HTTP interaction to be played back multiple times.
 #' Default: `FALSE`.
 #' @param serialize_with (character) Which serializer to use.
-#'  Valid values are "yaml" (default), the only one supported for now.
+#' Valid values are "yaml" (default) and "json". Note that you can have
+#' multiple cassettes with the same name as long as they use different
+#' serializers; so if you only want one cassette for a given cassette name,
+#' make sure to not switch serializers, or clean up files you no longer need.
 #' @param persist_with (character) Which cassette persister to
-#'  use. Default: "file_system". You can also register and use a
-#'  custom persister.
+#' use. Default: "file_system". You can also register and use a
+#' custom persister.
 #' @param preserve_exact_body_bytes (logical) Whether or not
 #' to base64 encode the bytes of the requests and responses for
 #' this cassette when serializing it. See also `preserve_exact_body_bytes`
@@ -41,6 +49,15 @@
 #'  will no longer be used. In addition, any newly recorded HTTP interactions
 #'  will be written to disk.
 #'
+#' @section Cassette options:
+#'
+#' Default values for arguments controlling cassette behavior are
+#' inherited from vcr's global configuration. See [`vcr_configure()`] for a
+#' complete list of options and their default settings. You can override these
+#' options for a specific cassette by changing an argument's value to something
+#' other than `NULL` when calling either `insert_cassette()` or
+#' `use_cassette()`.
+#'
 #' @section Behavior:
 #' This function handles a few different scenarios:
 #'
@@ -53,6 +70,10 @@
 #' we return with a useful message, and since we use `on.exit()`
 #' the cassette is still ejected even though there was an error,
 #' but you don't get an object back
+#' - whenever an empty cassette (a yml/json file) is found, we delete it
+#' before returning from the `use_cassette()` function call. we achieve
+#' this via use of `on.exit()` so an empty cassette is deleted even
+#' if there was an error in the code block you passed in
 #'
 #' @section Cassettes on disk:
 #' Note that _"eject"_ only means that the R session cassette is no longer
@@ -102,7 +123,7 @@
 #' # with httr
 #' library(vcr)
 #' library(httr)
-#' vcr_configure(dir = tempdir(), log = TRUE)
+#' vcr_configure(dir = tempdir(), log = TRUE, log_opts = list(file = file.path(tempdir(), "vcr.log")))
 #'
 #' use_cassette(name = "stuff350", {
 #'   res <- GET("https://httpbin.org/get")
@@ -129,22 +150,28 @@
 #' two; res2
 #' }
 
-use_cassette <- function(name, ..., record = "once",
-  match_requests_on = c("method", "uri"),
+use_cassette <- function(name, ...,
+  record = NULL,
+  match_requests_on = NULL,
   update_content_length_header = FALSE,
   allow_playback_repeats = FALSE,
-  serialize_with = "yaml", persist_with = "FileSystem",
-  preserve_exact_body_bytes = FALSE, re_record_interval = NULL,
-  clean_outdated_http_interactions = FALSE) {
+  serialize_with = NULL,
+  persist_with = NULL,
+  preserve_exact_body_bytes = NULL,
+  re_record_interval = NULL,
+  clean_outdated_http_interactions = NULL) {
 
-  cassette <- insert_cassette(
-    name, record = record, match_requests_on = match_requests_on,
+  cassette <- insert_cassette(name,
+    record = record,
+    match_requests_on = match_requests_on,
     update_content_length_header = update_content_length_header,
     allow_playback_repeats = allow_playback_repeats,
-    serialize_with = serialize_with, persist_with = persist_with,
+    serialize_with = serialize_with,
+    persist_with = persist_with,
     preserve_exact_body_bytes = preserve_exact_body_bytes,
     re_record_interval = re_record_interval,
-    clean_outdated_http_interactions = clean_outdated_http_interactions)
+    clean_outdated_http_interactions = clean_outdated_http_interactions
+  )
   if (is.null(cassette)) {
     force(...)
     return(NULL)
@@ -153,3 +180,9 @@ use_cassette <- function(name, ..., record = "once",
   cassette$call_block(...)
   return(cassette)
 }
+
+check_empty_cassette <- function(cas) {
+  if (!any(nzchar(readLines(cas$file())))) {
+    warning(empty_cassette_message, call. = FALSE)
+  }
+}
